data {
  // number of observations
  int<lower=0> N;
  
  // number of sessions
  int<lower=0> N_sessions;
  
  // number of predictors
  int<lower=0> K; 
  
  // predictor matrix
  matrix[N, K] X; 
  
  // session index
  int session [N];
  
  // number of sharks
  int count [N];
  
  // area covered (offset)
  vector [N] area;
  
  // test session index
  int LOGO;
}

parameters {
  // fixed effects
  vector[K] beta;
  
  // standard deviation of random effects
  real <lower = 0> sigma;
  
  // unscaled random effects
  vector[N_sessions] eta;
  
  //dispersion parameter
  real<lower=0> phi;
}

transformed parameters {
  // linear predictor for each observation
  vector[N] mu;
  
  // scaled random effects
  vector[N_sessions] u;
  
  u = sigma*eta;
  mu = X * beta + u[session] + log(area);
}

model {
  
  // use weakly informative priors
  beta ~ normal(0, 10);
  phi ~ gamma(0.01, 0.01);
  
  eta ~ normal(0, 1);
  sigma ~ exponential(1);
  
  for(n in 1:N){
    // exclude any data from left out group
    if(session[n] != LOGO){
     count[n] ~ neg_binomial_2(exp(mu[n]), phi); 
    }
  }
  
}

generated quantities{
  // simulated counts
  int count_rep [N];
  
  // LOGO log likelihood
  real log_lik = 0;
  
  for(n in 1:N){
    // randomly draw predictions
    count_rep[n] = neg_binomial_2_rng(exp(mu[n]), phi);
    
    // score left out group with log density
    if(session[n] == LOGO){
      log_lik += neg_binomial_2_lpmf(count[n] | exp(mu[n]), phi);
    }
  }
}

